OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "No se pudo enviar el mensaje a los siguientes usuarios: %s",
    "Preparing update" : "Preparando la actualización",
    "Turned on maintenance mode" : "Modo mantenimiento activado",
    "Turned off maintenance mode" : "Modo mantenimiento desactivado",
    "Maintenance mode is kept active" : "El modo mantenimiento aún está activo.",
    "Updating database schema" : "Actualizando el esquema del base de datos",
    "Updated database" : "Base de datos actualizada",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Checked database schema update" : "Actualización del esquema de base de datos revisado",
    "Checking updates of apps" : "Comprobar actualizaciones de apps",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Comprobar si se puede actualizar el esquema de la base de datos %s (esto puede tardar bastante tiempo, dependiendo del tamaño de la base de datos)",
    "Checked database schema update for apps" : "Comprobada la actualización del esquema de la base de datos para aplicaciones",
    "Updated \"%s\" to %s" : "Se ha actualizado \"%s\" a %s",
    "Repair warning: " : "Advertencia de reparación:",
    "Repair error: " : "Error que reparar:",
    "Set log level to debug" : "Establecer el nivel de registro a depuración",
    "Reset log level" : "Restablecer el nivel de registro",
    "Starting code integrity check" : "Comenzando comprobación de integridad de código",
    "Finished code integrity check" : "Terminando comprobación de integridad de código",
    "%s (3rdparty)" : "%s (tercer parte)",
    "%s (incompatible)" : "%s (incompatible)",
    "Following apps have been disabled: %s" : "Siguiendo aplicaciones ha sido deshabilitado: %s",
    "Already up to date" : "Ya actualizado",
    "Please select a file." : "Por favor, seleccione un archivo",
    "File is too big" : "El archivo es demasiado grande",
    "Invalid file provided" : "Archivo inválido",
    "No image or file provided" : "No se especificó ningún archivo o imagen",
    "Unknown filetype" : "Tipo de archivo desconocido",
    "Invalid image" : "Imagen inválida",
    "An error occurred. Please contact your admin." : "Un error ocurrió. Póngase en contacto con su administrador.",
    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
    "No crop data provided" : "No se proporcionó datos del recorte",
    "No valid crop data provided" : "Recorte inválido",
    "Crop is not square" : "El recorte no es cuadrado",
    "Couldn't reset password because the token is invalid" : "No se puede restablecer la contraseña porque el vale de identificación es inválido.",
    "Couldn't reset password because the token is expired" : "No se puede restablecer la contraseña porque el vale de identificación ha caducado.",
    "Couldn't send reset email. Please make sure your username is correct." : "No se pudo enviar el correo electrónico para el restablecimiento. Por favor, asegúrese de que su nombre de usuario es el correcto.",
    "Could not send reset email because there is no email address for this username. Please contact your administrator." : "No se pudo enviar el correo electrónico de restablecimiento porque no hay una dirección de correo electrónico para este nombre de usuario. Póngase en contacto con un administrador.",
    "%s password reset" : "%s restablecer contraseña",
    "Couldn't send reset email. Please contact your administrator." : "No pudo enviarse el correo para restablecer la contraseña. Por favor, contacte con su administrador.",
    "Sunday" : "Domingo",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sun." : "Dom.",
    "Mon." : "Lun.",
    "Tue." : "Mar.",
    "Wed." : "Mier.",
    "Thu." : "Jue.",
    "Fri." : "Vie.",
    "Sat." : "Sab.",
    "Su" : "Do",
    "Mo" : "Lu",
    "Tu" : "Ma",
    "We" : "Mi",
    "Th" : "Ju",
    "Fr" : "Vi",
    "Sa" : "Sa",
    "January" : "Enero",
    "February" : "Febrero",
    "March" : "Marzo",
    "April" : "Abril",
    "May" : "Mayo",
    "June" : "Junio",
    "July" : "Julio",
    "August" : "Agosto",
    "September" : "Septiembre",
    "October" : "Octubre",
    "November" : "Noviembre",
    "December" : "Diciembre",
    "Jan." : "Ene.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Abr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Ago.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dic.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Ha habido problemas durante la comprobación de la integridad del código. Más información…</a>",
    "Settings" : "Ajustes",
    "Saving..." : "Guardando...",
    "Dismiss" : "Descartar",
    "seconds ago" : "hace segundos",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Se ha enviado un enlace para restablecer su contraseña a su correo electrónico. Si usted no lo recibe en un tiempo razonable, revise su carpeta de spam/chatarra/basura.<br>Si no lo encuentra, consulte a su administrador local.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Sus archivos están cifrados. Si no ha activado la clave de recuperación, no habrá manera de recuperar los datos una vez su contraseña sea restablecida.<br /> Si no está seguro de lo que debe hacer, por favor contacte con su administrador antes de continuar.<br />¿Realmente desea continuar?",
    "I know what I'm doing" : "Sé lo que estoy haciendo",
    "Password can not be changed. Please contact your administrator." : "La contraseña no se puede cambiar. Por favor, contacte a su administrador.",
    "No" : "No",
    "Yes" : "Sí",
    "Choose" : "Seleccionar",
    "Error loading file picker template: {error}" : "Error al cargar plantilla del seleccionador de archivos: {error}",
    "Ok" : "Aceptar",
    "Error loading message template: {error}" : "Error al cargar plantilla del mensaje: {error}",
    "read-only" : "solo lectura",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} conflicto de archivo","{count} conflictos de archivo"],
    "One file conflict" : "Un conflicto de archivo",
    "New Files" : "Nuevos archivos",
    "Already existing files" : "Archivos ya existentes",
    "Which files do you want to keep?" : "¿Cuáles archivos desea mantener?",
    "If you select both versions, the copied file will have a number added to its name." : "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
    "Cancel" : "Cancelar",
    "Continue" : "Continuar",
    "(all selected)" : "(seleccionados todos)",
    "({count} selected)" : "({count} seleccionados)",
    "Error loading file exists template" : "Error cargando plantilla de archivo existente",
    "Very weak password" : "Contraseña muy débil",
    "Weak password" : "Contraseña débil",
    "So-so password" : "Contraseña pasable",
    "Good password" : "Contraseña buena",
    "Strong password" : "Contraseña muy buena",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Su servidor web aún no está configurado adecuadamente para permitir sincronización de archivos ya que la interfaz WebDAV parece no estar funcionando.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "Su servidor web no está configurado correctamente para resolver \"{url}\". Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Este servidor no tiene una conexión a Internet. Esto significa que algunas de las características como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones o instalación de aplicaciones de terceros no funcionan. Podría no funcionar el acceso a los archivos de forma remota y el envío de correos electrónicos de notificación. Sugerimos habilitar la conexión a Internet de este servidor, si quiere tener todas las funciones.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La memoria caché no ha sido configurada. Para aumentar su rendimiento por favor configure memcache si está disponible. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "/dev/urandom no es legible por PHP el mismo es altamente desalentado por razones de seguridad. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
    "Your PHP version ({version}) is no longer <a target=\"_blank\" href=\"{phpLink}\">supported by PHP</a>. We encourage you to upgrade your PHP version to take advantage of performance and security updates provided by PHP." : "Su versión PHP ({version}) ya no es <a target=\"_blank\" href=\"{phpLink}\">respaldada por PHP</a>.  Recomendamos actualizar su versión de PHP para aprovechar las actualizaciones de rendimiento y seguridad proporcionadas por PHP.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>." : "La configuración de las cabeceras inversas del proxy son incorrectas, o está accediendo a ownCloud desde un proxy confiable. Si no está accediendo a ownCloud desde un proxy certificado y confiable, este es un problema de seguridad y puede permitirle a un hacker camuflar su dirección IP a ownCloud. Más información puede ser encontrada en nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "memcached es un sistema de cache distribuido. pero ha sido instalado por error el modulo PHP memcache.\nConsulte <a target=\"_blank\" href=\"{wikiLink}\">memcached wiki acerca de ambos modulos</a>",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Algunos archivos no han superado la comprobación de integridad. Para más información sobre cómo resolver este inconveniente consulte nuestra <a target=\"_blank\" href=\"{docLink}\">documentación</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Lista de archivos inválidos…</a> / <a href=\"{rescanEndpoint}\">Reescanear…</a>)",
    "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Le sugerimos encarecidamente que configure su servidor web de modo que el directorio de datos ya no sea accesible o que mueva el directorio de datos fuera de la raíz de documentos del servidor web.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "La \"{header}\" cabecera HTTP no está configurado para ser igual a \"{expected}\". Esto puede suponer un riesgo para la seguridad o la privacidad, por lo que se recomienda ajustar esta opción.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\">security tips</a>." : "La cabecera HTTP \"Strict-Transport-Security\" no está configurada en al menos \"{segundos}\" segundos. Para una mejor seguridad recomendamos que habilite HSTS como se describe en nuestros <a href=\"{docUrl}\">consejos de seguridad</a>.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Está ingresando a este sitio de internet vía HTTP. Le sugerimos enérgicamente que configure su servidor que utilice HTTPS como se describe en nuestros <a href=\"{docUrl}\">consejos de seguridad</a>.",
    "Shared" : "Compartido",
    "Shared with {recipients}" : "Compartido con {recipients}",
    "Error" : "Error",
    "Error while sharing" : "Error al compartir",
    "Error while unsharing" : "Error al dejar de compartir",
    "Error setting expiration date" : "Error estableciendo fecha de caducidad",
    "The public link will expire no later than {days} days after it is created" : "El vínculo público no expirará antes de {days} desde que se creó",
    "Set expiration date" : "Establecer fecha de caducidad",
    "Expiration" : "Expira en:",
    "Expiration date" : "Fecha de caducidad",
    "Choose a password for the public link" : "Elija una contraseña para el enlace publico",
    "Sending ..." : "Enviando...",
    "Email sent" : "Correo electrónico enviado",
    "Resharing is not allowed" : "No se permite compartir de nuevo",
    "Share link" : "Enlace compartido",
    "Link" : "Enlace",
    "Password protect" : "Protección con contraseña",
    "Password" : "Contraseña",
    "Allow editing" : "Permitir edición",
    "Email link to person" : "Enviar enlace por correo electrónico a una persona",
    "Send" : "Enviar",
    "Shared with you and the group {group} by {owner}" : "Compartido contigo y el grupo {group} por {owner}",
    "Shared with you by {owner}" : "Compartido contigo por {owner}",
    "group" : "grupo",
    "remote" : "remoto",
    "notify by email" : "notificar por correo electrónico",
    "Unshare" : "Dejar de compartir",
    "can share" : "puede compartir",
    "can edit" : "puede editar",
    "create" : "crear",
    "change" : "cambio",
    "delete" : "eliminar",
    "access control" : "control de acceso",
    "Could not unshare" : "No se puede quitar el comparto",
    "Share details could not be loaded for this item." : "No se han podido cargar los detalles de compartición para este elemento.",
    "No users or groups found for {search}" : "No se han encontrado usuarios ni grupos para {search}",
    "An error occured. Please try again" : "Un error ocurrió. Por favor reinténtelo nuevamente.",
    "{sharee} (group)" : "{sharee} (grupo)",
    "{sharee} (at {server})" : "{sharee} (en {server})",
    "{sharee} (remote)" : "{sharee} (remoto)",
    "Share" : "Compartir",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Comparta con personas en otros ownClouds utilizando la sintáxis username@example.com/owncloud",
    "Share with users or groups …" : "Compartir con usuarios o grupos ...",
    "Share with users, groups or remote users …" : "Comparte con usuarios, grupos o usuarios remotos...",
    "Error removing share" : "Error quitando el comparto",
    "Warning" : "Precaución",
    "Error while sending notification" : "Error mientras se enviaba la notificación",
    "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
    "not assignable" : "no asignable",
    "invisible" : "invisible",
    "({scope})" : "({scope})",
    "Delete" : "Eliminar",
    "Rename" : "Renombrar",
    "Collaborative tags" : "Etiquetas colaborativas",
    "The object type is not specified." : "El tipo de objeto no está especificado.",
    "Enter new" : "Ingresar nueva",
    "Add" : "Agregar",
    "Edit tags" : "Editar etiquetas",
    "Error loading dialog template: {error}" : "Error al cargar plantilla de diálogo: {error}",
    "No tags selected for deletion." : "No hay etiquetas seleccionadas para borrar.",
    "unknown text" : "texto desconocido",
    "Hello world!" : "¡Hola mundo!",
    "sunny" : "soleado",
    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
    "Hello {name}" : "Hola {name}",
    "_download %n file_::_download %n files_" : ["descargar %n ficheros","descargar %n archivos"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
    "Updating {productName} to version {version}, this may take a while." : "Actualizando {productName} a la versión {version}. Esto puede tardar un poco.",
    "An error occurred." : "Ocurrió un error.",
    "Please reload the page." : "Recargue/Actualice la página",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La actualización tuvo un problema. Para más información <a href=\"{url}\">consulta nuestro artículo del foro</a> para arreglar este problema.",
    "The update was unsuccessful. " : "La actualización ha fallado.",
    "The update was successful. There were warnings." : "La actualización fue exitosa. Había advertencias.",
    "The update was successful. Redirecting you to ownCloud now." : "La actualización se ha realizado con éxito. Redireccionando a ownCloud ahora.",
    "Searching other places" : "Buscando en otros lugares",
    "No search results in other folders" : "Ningún resultado de búsqueda en otras carpetas",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} resultado de búsqueda en otra carpeta","{count} resultados de búsqueda en otras carpetas"],
    "Personal" : "Personal",
    "Users" : "Usuarios",
    "Apps" : "Aplicaciones",
    "Admin" : "Administración",
    "Help" : "Ayuda",
    "Error loading tags" : "Error al cargar las etiquetas.",
    "Tag already exists" : "La etiqueta ya existe",
    "Error deleting tag(s)" : "Error al borrar etiqueta(s)",
    "Error tagging" : "Error al etiquetar",
    "Error untagging" : "Error al quitar etiqueta",
    "Error favoriting" : "Error al marcar como favorito",
    "Error unfavoriting" : "Error al quitar como favorito",
    "Access forbidden" : "Acceso denegado",
    "File not found" : "Archivo no encontrado",
    "The specified document has not been found on the server." : "El documento indicado no se ha encontrado en el servidor.",
    "You can click here to return to %s." : "Puede hacer clic aquí para volver a %s.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hola:\n\nTan solo queremos informarte que %s compartió %s contigo.\nMíralo aquí: %s\n\n",
    "The share will expire on %s." : "El objeto dejará de ser compartido el %s.",
    "Cheers!" : "¡Saludos!",
    "Internal Server Error" : "Error interno del servidor",
    "The server encountered an internal error and was unable to complete your request." : "El servidor ha encontrado un error y no puede completar la solicitud.",
    "Please contact the server administrator if this error reappears multiple times, please include the technical details below in your report." : "Por favor, contacte con el administrador del servidor si este error reaparece múltiples veces. Incluya asimismo los detalles técnicos que se muestran a continuación.",
    "More details can be found in the server log." : "Pueden verse más detalles en el registro del servidor.",
    "Technical details" : "Detalles técnicos",
    "Remote Address: %s" : "Dirección remota: %s",
    "Request ID: %s" : "ID de la solicitud: %s",
    "Type: %s" : "Tipo: %s",
    "Code: %s" : "Código: %s",
    "Message: %s" : "Mensaje: %s",
    "File: %s" : "Archivo: %s",
    "Line: %s" : "Línea: %s",
    "Trace" : "Trazas",
    "Security warning" : "Advertencia de seguridad",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Para información de cómo configurar apropiadamente su servidor, por favor vea la <a href=\"%s\" target=\"_blank\">documentación</a>.",
    "Create an <strong>admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
    "Username" : "Nombre de usuario",
    "Storage & database" : "Almacenamiento y base de datos",
    "Data folder" : "Directorio de datos",
    "Configure the database" : "Configurar la base de datos",
    "Only %s is available." : "Solo %s está disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
    "For more details check out the documentation." : "Para más detalles revisar la documentación.",
    "Database user" : "Usuario de la base de datos",
    "Database password" : "Contraseña de la base de datos",
    "Database name" : "Nombre de la base de datos",
    "Database tablespace" : "Espacio de tablas de la base de datos",
    "Database host" : "Host de la base de datos",
    "Performance warning" : "Advertencia de rendimiento",
    "SQLite will be used as database." : "Se utilizará SQLite como base de datos.",
    "For larger installations we recommend to choose a different database backend." : "Para grandes instalaciones recomendamos seleccionar una base de datos diferente",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "El uso de SQLite esta desaconsejado especialmente cuando se usa el cliente de escritorio para sincronizar los ficheros.",
    "Finish setup" : "Completar la instalación",
    "Finishing …" : "Finalizando...",
    "Need help?" : "¿Necesita ayuda?",
    "See the documentation" : "Vea la documentación",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hola:<br><br>Te comentamos que %s compartió <strong>%s</strong> contigo.<br><a href=\"%s\">¡Échale un vistazo!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Esta aplicación requiere JavaScript para operar correctamente. Por favor, {linkstart}habilite JavaScript{linkend} y recargue la página.",
    "Log out" : "Salir",
    "Search" : "Buscar",
    "Server side authentication failed!" : "La autenticación a fallado en el servidor.",
    "Please contact your administrator." : "Por favor, contacte con el administrador.",
    "An internal error occured." : "Un error interno ocurrió.",
    "Please try again or contact your administrator." : "Por favor reintente nuevamente o contáctese con su administrador.",
    "Log in" : "Ingresar",
    "Wrong password. Reset it?" : "Contraseña incorrecta. ¿Restablecerla?",
    "Wrong password." : "Contraseña incorrecta.",
    "Stay logged in" : "Permanecer autenticado",
    "Alternative Logins" : "Inicios de sesión alternativos",
    "Use the following link to reset your password: {link}" : "Utilice el siguiente enlace para restablecer su contraseña: {link}",
    "New password" : "Nueva contraseña",
    "New Password" : "Contraseña nueva",
    "Reset password" : "Restablecer contraseña",
    "This ownCloud instance is currently in single user mode." : "Esta instalación de ownCloud se encuentra en modo de usuario único.",
    "This means only administrators can use the instance." : "Esto quiere decir que solo un administrador puede usarla.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
    "Thank you for your patience." : "Gracias por su paciencia.",
    "You are accessing the server from an untrusted domain." : "Está accediendo al servidor desde un dominio inseguro.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Contacte con su administrador. Si usted es el administrador, configure \"trusted_domains\" en config/config.php. En config/config.sample.php se encuentra un ejemplo para la configuración.",
    "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Dependiendo de su configuración, como administrador, debería poder usar el botón de abajo para confiar en este dominio.",
    "Add \"%s\" as trusted domain" : "Agregar \"%s\" como dominio de confianza",
    "App update required" : "Es necesaria una actualización en la aplicación",
    "%s will be updated to version %s" : "%s será actualizada a la versión %s",
    "These apps will be updated:" : "Estas aplicaciones serán actualizadas:",
    "These incompatible apps will be disabled:" : "Estas aplicaciones incompatibles serán deshabilitadas:",
    "The theme %s has been disabled." : "El tema %s ha sido desactivado.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Antes de proceder, asegúrese de que se haya hecho un respaldo de la base de datos, la carpeta de configuración y la carpeta de datos.",
    "Start update" : "Iniciar actualización",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Para evitar tiempos de espera en grandes instalaciones, en su lugar puede ejecutar el siguiente comando desde el directorio de instalación:",
    "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, por lo que puede llevar un tiempo.",
    "This page will refresh itself when the %s instance is available again." : "La página se refrescará cuando la instalación %s vuelva a estar disponible.",
    "Repair error: " : "Error que reparar:",
    "Password can not be changed. Please contact your administrator." : "La contraseña no se puede cambiar. Por favor, contacte a su administrador."
},
"nplurals=2; plural=(n != 1);");
